/*
' Name:					fn_student_profile_base_view
' Description:			basis for the majors, minor, concentrations that are in
'							 dim_student_profile
'
'							Grain:  pidm / term_code / sgb_term_code / active / ord / seqno
'
' Creator:				Dan Rickner & Ben Roller
' Create Date:			May 08, 2009
' ------------------------------------------------------------------------------
' Modification Date:	June 17, 2009
' Modified by:			Tim Channell
' Change Log:		1.	switched to 'new' sgvacur_order rule - sgvacur_order = 1 is primary curricula.
'							this simplifies the subqueries greatly.
'-------------------------------------------------------------------------------
' Modification Date:	April 8, 2010
' Modified by:			Dan Rickner
' Change Log:		1. converted to a function
'-------------------------------------------------------------------------------
' Modification Date:	October 30, 2010 (outside by fire)
' Modified by:			Dan Rickner
' Change Log:		1. added isnull() on student_type_code trying to fix issue with
'							class_level in dim_student / student_profile case statement
'-------------------------------------------------------------------------------
' Modification Date:	
' Modified by:			
' Change Log:		1. 
'-------------------------------------------------------------------------------
*/

if exists(select 1 from information_schema.tables where table_name = 'student_profile_base_view_dump')
drop table student_profile_base_view_dump;

select
	base.*,
	curricula1.sgvacur_admt_code				as admit_type_code,
	isnull(curricula1.sgvacur_styp_code, curricula1.sgvacur_stdn_styp_code)				as student_type_code,
	curricula1.sgvacur_site_code				as student_site_code,
	curricula1.sgvacur_levl_code				as primary_levl_code,
	curricula1.sgvacur_program					as primary_program,
	curricula1.sgvacur_coll_code				as primary_coll_code,
	curricula1.sgvacur_degc_code				as primary_degc_code,
	curricula1.sgvacur_majr_code_1			as primary_majr_code1,
	curricula1.sgvacur_majr_code_2			as primary_majr_code2,
	curricula1.sgvacur_majr_code_minr_1		as primary_minr_code1,
	curricula1.sgvacur_majr_code_minr_2		as primary_minr_code2,
	curricula1.sgvacur_majr_code_conc_1		as primary_conc_code1,
	curricula1.sgvacur_attach_majr_conc_1	as primary_conc_code1_attach,
	curricula1.sgvacur_majr_code_conc_2		as primary_conc_code2,
	curricula1.sgvacur_attach_majr_conc_2	as primary_conc_code2_attach,
	curricula1.sgvacur_majr_code_conc_3		as primary_conc_code3,
	curricula1.sgvacur_attach_majr_conc_3	as primary_conc_code3_attach,
	curricula1.sgvacur_majr_code_conc_4		as primary_conc_code4,
	curricula1.sgvacur_attach_majr_conc_4	as primary_conc_code4_attach,
	curricula1.sgvacur_majr_code_conc_5		as primary_conc_code5,
	curricula1.sgvacur_attach_majr_conc_5	as primary_conc_code5_attach,
	curricula1.sgvacur_majr_code_conc_6		as primary_conc_code6,
	curricula1.sgvacur_attach_majr_conc_6	as primary_conc_code6_attach,
	curricula2.sgvacur_levl_code				as secondary_levl_code,
	curricula2.sgvacur_program					as secondary_program,
	curricula2.sgvacur_coll_code				as secondary_coll_code,
	curricula2.sgvacur_degc_code				as secondary_degc_code,
	curricula2.sgvacur_majr_code_1			as secondary_majr_code1,
	curricula2.sgvacur_majr_code_2			as secondary_majr_code2,
	curricula2.sgvacur_majr_code_minr_1		as secondary_minr_code1,
	curricula2.sgvacur_majr_code_minr_2		as secondary_minr_code2,
	curricula2.sgvacur_majr_code_conc_1		as secondary_conc_code1,
	curricula2.sgvacur_attach_majr_conc_1	as secondary_conc_code1_attach,
	curricula2.sgvacur_majr_code_conc_2		as secondary_conc_code2,
	curricula2.sgvacur_attach_majr_conc_2	as secondary_conc_code2_attach,
	curricula2.sgvacur_majr_code_conc_3		as secondary_conc_code3,
	curricula2.sgvacur_attach_majr_conc_3	as secondary_conc_code3_attach,
	curricula2.sgvacur_majr_code_conc_4		as secondary_conc_code4,
	curricula2.sgvacur_attach_majr_conc_4	as secondary_conc_code4_attach,
	curricula2.sgvacur_majr_code_conc_5		as secondary_conc_code5,
	curricula2.sgvacur_attach_majr_conc_5	as secondary_conc_code5_attach,
	curricula2.sgvacur_majr_code_conc_6		as secondary_conc_code6,
	curricula2.sgvacur_attach_majr_conc_6	as secondary_conc_code6_attach
	into student_profile_base_view_dump
from
(
	select
		term.*,
		pri.prim_term_code,
		pri.ord1,
		pri.seqno1,
		sec.sec_term_code,
		sec.ord2,
		sec.seqno2
	from
	(	-- get all curricula terms
		select	-- primary curricula terms
			sgvacur_pidm										as pidm,
			sgvacur_stdn_term_code_eff						as sgb_term_code,
			max(sgvacur_active_ind)							as active
		from sgvacur 
		where sgvacur_order = 1 and sgvacur_active_ind = 'Y'
--and sgvacur_pidm = 177505
		group by 
			sgvacur_pidm,
			sgvacur_term_code,
			sgvacur_stdn_term_code_eff
	union	-- secondary curricula terms
		select 
			sgvacur_pidm						as pidm,
			sgvacur_stdn_term_code_eff		as sgb_term_code,
			max(sgvacur_active_ind)			as active
		from sgvacur
		where sgvacur_order > 1 and sgvacur_active_ind = 'Y' 
--and sgvacur_pidm = 177505
		group by 
			sgvacur_pidm,
			sgvacur_term_code,
			sgvacur_stdn_term_code_eff
	) as term
	left outer join
	(	-- primary curricula seqno and order numbers
		select
			sgvacur_pidm										as pidm,
			sgvacur_stdn_term_code_eff						as sgb_term_code,
			max(sgvacur_term_code)							as prim_term_code,
			max(sgvacur_active_ind)							as active,	-- just for joins at bottom
			min(sgvacur_order)								as ord1,
			max(sgvacur_seqno)								as seqno1
		from sgvacur 
		where sgvacur_order = 1 and sgvacur_active_ind = 'Y'
--and sgvacur_pidm = 177505
		group by 
			sgvacur_pidm,
			sgvacur_stdn_term_code_eff
	) as pri on (pri.pidm = term.pidm
				and pri.sgb_term_code = term.sgb_term_code)
	left outer join
	(	-- secondary curricula seqno and order numbers
		select
			seq.pidm,
			seq.sgb_term_code,
			seq.term_code				as sec_term_code,
			seq.active					as active,
			min(ord.sgvacur_order)	as ord2,	-- might have > 1 secondary, so we want lowest one
			seq.seqno2
		from
		(	-- highest sequence number on secondary curricula (not order 1)
			select 
				sgvacur_pidm						as pidm,
				sgvacur_stdn_term_code_eff		as sgb_term_code,
				max(sgvacur_term_code)			as term_code,
				max(sgvacur_active_ind)			as active,
				max(sgvacur_seqno)				as seqno2
			from sgvacur
		where sgvacur_order > 1 and sgvacur_active_ind = 'Y' 
--and sgvacur_pidm = 177505
			group by 
				sgvacur_pidm,
				sgvacur_stdn_term_code_eff
		) as seq
		inner join sgvacur ord on ( seq.pidm				= ord.sgvacur_pidm
										and seq.sgb_term_code	= ord.sgvacur_stdn_term_code_eff
										and seq.term_code			= ord.sgvacur_term_code
										and seq.active				= ord.sgvacur_active_ind
										and seq.seqno2				= ord.sgvacur_seqno)
		group by
			seq.pidm,
			seq.sgb_term_code,
			seq.term_code,
			seq.active,
			seq.seqno2
	) as sec on (sec.pidm		 		= term.pidm
				and sec.sgb_term_code	= term.sgb_term_code)
) as base
---------------------------------------------------------------------------------------------------
-- First Curricula
left outer join 
sgvacur curricula1 on (curricula1.sgvacur_pidm 						= base.pidm
						 and curricula1.sgvacur_term_code				= base.prim_term_code
						 and curricula1.sgvacur_stdn_term_code_eff	= base.sgb_term_code
						 and curricula1.sgvacur_active_ind				= base.active
						 and curricula1.sgvacur_order						= base.ord1
						 and curricula1.sgvacur_seqno						= base.seqno1)
---------------------------------------------------------------------------------------------------
-- Second Curricula
left outer join
sgvacur curricula2 on (curricula2.sgvacur_pidm 						= base.pidm
						 and curricula2.sgvacur_term_code				= base.sec_term_code
						 and curricula2.sgvacur_stdn_term_code_eff	= base.sgb_term_code
						 and curricula2.sgvacur_active_ind				= base.active
						 and curricula2.sgvacur_order						= base.ord2
						 and curricula2.sgvacur_seqno						= base.seqno2);



-- put a clustered index on the identifying transform fields
exec config..sp_create_index 'student_profile_base_view_dump', 'stage'
